"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSimpleContext = exports.SimpleContext = void 0;
const async_hooks_1 = require("async_hooks");
class SimpleContext {
    constructor() {
        this.properties = {};
        this.asyncLocalStorage = new async_hooks_1.AsyncLocalStorage();
    }
    get(key) {
        return this.getForkProperty(key);
    }
    set(key, value) {
        return this.setForkProperty(key, value);
    }
    fork(callback) {
        const forkedProperties = { ...this.properties };
        if (callback) {
            return this.asyncLocalStorage.run(forkedProperties, callback);
        }
        this.asyncLocalStorage.enterWith(forkedProperties);
        return this;
    }
    setForkProperty(key, value) {
        const store = this.asyncLocalStorage.getStore();
        store ? (store[key] = value) : (this.properties[key] = value);
    }
    getForkProperty(key) {
        const store = this.asyncLocalStorage.getStore();
        return store
            ? store[key]
            : this.properties[key];
    }
}
exports.SimpleContext = SimpleContext;
function createSimpleContext() {
    return new SimpleContext();
}
exports.createSimpleContext = createSimpleContext;
